==> haskell-aeson-warning-parser-0.1.1-80-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-TkU8sEgptJL6suKYzpBmz
key:                  aeson-warning-parser-0.1.1-TkU8sEgptJL6suKYzpBmz
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  011f87244ce865f2aff6475991207e62
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-TkU8sEgptJL6suKYzpBmz
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    generic-deriving-1.14.6-JQOxBghRoeu5pAKXaX4yl5
    rio-0.1.22.0-2S3DgnoH0cl6ZJdvxjSsI5
    rio-prettyprint-0.1.8.0-IatOwnHVZpLBD126SHPF3E text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-warning-parser-0.1.1-81-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-LLjXjVi4OLsDzwxddUvmo4
key:                  aeson-warning-parser-0.1.1-LLjXjVi4OLsDzwxddUvmo4
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  c2ebaa73e99655c135a504fa0a4c68e2
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-LLjXjVi4OLsDzwxddUvmo4
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    generic-deriving-1.14.6-EuFohhXhdng2D0y7uvFJO5
    rio-0.1.22.0-9YWPFaDDA8QAvZjRU1ibSo
    rio-prettyprint-0.1.8.0-1E5SvMAHYizIzsYMRS3OM text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
